Function black_box
fn black_box<T>(dummy: T) -> T
An identity function that hints to the compiler to be maximally pessimistic about what
black_box could do.
See std::hint::black_box for details.
black_boxfn black_box<T>(dummy: T) -> T
An identity function that hints to the compiler to be maximally pessimistic about what
black_box could do.
See std::hint::black_box for details.