Function run_tests_console
fn run_tests_console(opts: &TestOpts, tests: Vec<TestDescAndFn>) -> Result<bool>
A simple console test runner. Runs provided tests reporting process and results to the stdout.
run_tests_consolefn run_tests_console(opts: &TestOpts, tests: Vec<TestDescAndFn>) -> Result<bool>
A simple console test runner. Runs provided tests reporting process and results to the stdout.