Struct Summary
struct Summary { ... }
Extracted collection of all the summary statistics of a sample set.
Fields
sum: f64min: f64max: f64mean: f64median: f64var: f64std_dev: f64std_dev_pct: f64median_abs_dev: f64median_abs_dev_pct: f64quartiles: (f64, f64, f64)iqr: f64
Implementations
impl Summary
fn new(samples: &[f64]) -> SummaryConstructs a new summary of a sample set.
impl Clone for Summary
fn clone(self: &Self) -> Summary
impl Copy for Summary
impl Debug for Summary
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Summary
impl PartialEq for Summary
fn eq(self: &Self, other: &Summary) -> bool
impl RefUnwindSafe for Summary
impl Send for Summary
impl StructuralPartialEq for Summary
impl Sync for Summary
impl Unpin for Summary
impl UnsafeUnpin for Summary
impl UnwindSafe for Summary
impl<T> Any for Summary
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Summary
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Summary
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Summary
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Summary
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Summary
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Summary
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Summary
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Summary
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>