Struct TestOpts

struct TestOpts { ... }

Fields

list: bool
filters: Vec<String>
filter_exact: bool
force_run_in_process: bool
exclude_should_panic: bool
run_ignored: RunIgnored
run_tests: bool
bench_benchmarks: bool
logfile: Option<PathBuf>
nocapture: bool
color: ColorConfig
format: OutputFormat
shuffle: bool
shuffle_seed: Option<u64>
test_threads: Option<usize>
skip: Vec<String>
time_options: Option<TestTimeOptions>
fail_fast: bool

Stop at first failing test. May run a few more tests due to threading, but will abort as soon as possible.

options: Options

Implementations

impl TestOpts

fn use_color(self: &Self) -> bool

impl Debug for TestOpts

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for TestOpts

impl RefUnwindSafe for TestOpts

impl Send for TestOpts

impl Sync for TestOpts

impl Unpin for TestOpts

impl UnsafeUnpin for TestOpts

impl UnwindSafe for TestOpts

impl<T> Any for TestOpts

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TestOpts

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TestOpts

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for TestOpts

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for TestOpts

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TestOpts

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TestOpts

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>